%define _ldapsubdir openldap
%define _useldbm 1
%define _databasedir /var/lib/%{_ldapsubdir}
%define _mig_version 44

Summary: Lightweight Directory Access Protocol clients/servers
Name: openldap
Version: 2.1.30
Release: 7tr
Source0: ftp://ftp.openldap.org/pub/OpenLDAP/openldap-release/openldap-%{version}.tgz
Source1: openldap.init
Source2: openldap-slapd.conf
Source3: ftp://ftp.padl.com/pub/MigrationTools-%{_mig_version}.tar.gz
# This is http://www.padl.com/OSS/MigrationTools.html converted to text
Source4: openldap-migration-tools.txt
Source5: openldap-rfc822-MailMember.schema
Source6: openldap-autofs.schema
Patch0: openldap-2.1.17-config.patch
# Patches by Red Hat which seemed useful
Patch1: openldap-2.1.17-string.patch
Patch2: openldap-1.2.11-cldap.patch
Patch3: openldap-2.1.17-syslog.patch
Patch4: openldap-2.0.11-ldaprc.patch
Patch5: openldap-2.1.17-susesec.patch
Patch6: openldap-2.1.30-tls_fix_connection.patch
Patch21: MigrationTools-38-instdir.patch
Patch22: MigrationTools-36-mktemp.patch
Patch23: MigrationTools-27-simple.patch
Patch24: MigrationTools-26-suffix.patch
Patch25: MigrationTools-44-schema.patch
Patch26: openldap-CVE-2006-4600.patch
Patch27: openldap-CVE-2006-5779.patch
URL: http://www.openldap.org/
License: Freely distributable
Group: Trustix Official
BuildRoot: /var/tmp/%{name}-%{version}-root
BuildRequires: openssl-devel tcp_wrappers cyrus-sasl-devel
%if !%{_useldbm}
BuildRequires: db4-devel 
%endif

%description
LDAP servers and clients, as well as interfaces to other protocols.
Note that this does not include the slapd interface to X.500 and
therefore does not require the ISODE package. 

%package devel
Summary:  LDAP development files
Group: Trustix Official
Requires: %{name}, %{name}-libs

%description devel
Header files and libraries for developing applications that use LDAP.

%package servers
Summary: LDAP servers
Group: Trustix Official
Provides: slapd, slurpd
Prereq: chkconfig, tsl-utils
Requires: %{name}, %{name}-libs, cyrus-sasl > 2.0, openssl
%if !%{_useldbm}
BuildRequires: db4
%endif

%description servers
OpenLDAP is an open-source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. This package contains the slapd and slurpd servers,
migration scripts, and related files.

%package libs
Summary: LDAP runtime libraries
Group: Trustix Official
Requires: cyrus-sasl > 2.0, openssl

%description libs
Runtime libraries needed for dynamic linking og applications against the LDAP
framework.

%package utils
Summary: LDAP client utilities
Group: Trustix Official
Requires: %{name}-libs

%description utils
The utils present in the openLDAP suite.

%prep

%setup -q -a 3
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
pushd MigrationTools-%{_mig_version}
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
popd
%patch26 -p1
%patch27 -p0

%build
CFLAGS="$RPM_OPT_FLAGS" \
./configure --prefix=/usr \
            --datadir=/usr/share \
            --disable-sql \
            --enable-cldap \
            --enable-crypt \
	    --enable-dns \
            --enable-dynamic \
            --enable-modules \
            --enable-local \
            --enable-passwd \
            --enable-phonetic \
            --enable-shared \
            --enable-shell \
            --enable-spasswd \
            --enable-static \
            --enable-wrappers \
            --libexecdir=/usr/sbin \
            --localstatedir=/var/run \
            --mandir=/usr/share/man \
            --sysconfdir=/etc \
            --with-cyrus-sasl \
            --with-slapd \
            --with-slurpd \
            --with-subdir=%{_ldapsubdir} \
            --with-threads=posix \
            --with-tls \
            --without-ldapd \
	    --with-sql-module=dynamic \
%if %{_useldbm}
            --disable-bdb \
            --enable-ldbm
%else

%endif

#make LDFLAGS="-ldb -lmysqlclient"
make


%install
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT

install -d $RPM_BUILD_ROOT%{_sysconfdir}/%{_ldapsubdir}
install -d $RPM_BUILD_ROOT%{_initdir}
install -d -m 700 $RPM_BUILD_ROOT/var/%{_ldapsubdir}

# do not use %makeinstll here, the openldap Makefile is broken
make install DESTDIR=$RPM_BUILD_ROOT

install -m755 %{SOURCE1} $RPM_BUILD_ROOT%{_initdir}/ldap
install -m600 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/%{_ldapsubdir}/slapd.conf
echo localhost > $RPM_BUILD_ROOT%{_sysconfdir}/%{_ldapsubdir}/ldapserver
chmod +x $RPM_BUILD_ROOT%{_libdir}/lib*.so.*
strip $RPM_BUILD_ROOT/usr/{*bin/*,lib/lib*.so.*.*.*} ||:
mkdir -p $RPM_BUILD_ROOT%{_databasedir}

# Another hack to make the default configs available as docs
cp %{SOURCE2} slapd.conf
cp libraries/libldap/ldap.conf ldap.conf

# Install MigrationTools.
mkdir -p $RPM_BUILD_ROOT%{_datadir}/openldap/migration
install -m 755 MigrationTools-%{_mig_version}/migrate_* \
        $RPM_BUILD_ROOT%{_datadir}/openldap/migration/
install -m 644 MigrationTools-%{_mig_version}/README %{SOURCE4} \
        $RPM_BUILD_ROOT%{_datadir}/openldap/migration/
cp MigrationTools-%{_mig_version}/README README.migration
cp %{SOURCE4} TOOLS.migration

# Add some more schema for the sake of migration scripts.
install -d -m755 $RPM_BUILD_ROOT%{_sysconfdir}/openldap/schema/trustix
install -m644 %{SOURCE5} $RPM_BUILD_ROOT%{_sysconfdir}/openldap/schema/trustix/rfc822-MailMember.schema
install -m644 %{SOURCE6} $RPM_BUILD_ROOT%{_sysconfdir}/openldap/schema/trustix/autofs.schema


%if %{_useldbm}
# Change the database to ldbm.
perl -pi -e "s|bdb|ldbm|g" $RPM_BUILD_ROOT/%{_sysconfdir}/%{_ldapsubdir}/slapd.conf
%endif

# The vacuum cleaner
find $RPM_BUILD_ROOT -name \*~ | xargs rm -f


%post
/sbin/ldconfig


%postun
/sbin/ldconfig

%pre
if [ -z "`getent group slapd`" ]; then
        /usr/sbin/groupadd -g 111 slapd
fi
if [ -z "`getent passwd slapd`" ]; then
        /usr/sbin/useradd -d /no/dir -M -s /bin/false \
        -g slapd -u 111 slapd
fi 

%post servers
/sbin/chkconfig --add ldap
/sbin/restart_maybe ldap


%preun servers
if [ "$1" = 0 ] ; then
  %{_initdir}/ldap stop > /dev/null || :
  /sbin/chkconfig --del ldap
fi


%clean
[ -n "$RPM_BUILD_ROOT" -a "$RPM_BUILD_ROOT" != / ] && rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,0755)
%doc ANNOUNCEMENT CHANGES COPYRIGHT INSTALL README
%doc doc/rfc/rfc* ldap.conf slapd.conf
%dir /etc/%{_ldapsubdir}
%config(noreplace) /etc/%{_ldapsubdir}/ldapserver
%config(noreplace) /etc/%{_ldapsubdir}/ldap*.conf
%dir /etc/%{_ldapsubdir}/schema
/etc/%{_ldapsubdir}/schema/README*
%config(noreplace) /etc/%{_ldapsubdir}/schema/*.schema*
%dir /etc/%{_ldapsubdir}/schema/trustix
%config(noreplace) /etc/%{_ldapsubdir}/schema/trustix/*.schema*
%attr(0755,root,root) %dir %{_datadir}/openldap
%{_datadir}/openldap/migration
%{_datadir}/%{_ldapsubdir}/ucdata
%{_mandir}/man5/ldap.conf.5*

%files devel
%defattr(-,root,root,0755)
%doc doc/drafts
%{_includedir}/*.h
%{_libdir}/lib*.so
%{_libdir}/lib*.*a
%{_mandir}/man3/*

%files servers
%defattr(-,root,root,0755)
%doc README.migration TOOLS.migration
%config(noreplace) %attr(640,root,slapd) /etc/%{_ldapsubdir}/slapd.conf
%{_initdir}/ldap
%dir %attr(700,slapd,slapd) %{_databasedir}
%{_sbindir}/*
%{_mandir}/man5/ldif.5*
%{_mandir}/man5/slapd*.5*
%{_mandir}/man8/*

%files libs
%defattr(-,root,root,0755)
%{_libdir}/lib*.so.*

%files utils
%defattr(-,root,root,0755)
%{_bindir}/*
%{_mandir}/man1/*


%changelog
* Tue Nov 21 2006 Nived Gopalan <nived at trustix dot org> 2.1.30-7tr
- SECURITY Fix: Evgeny Legerov has reported a vulnerability in OpenLDAP,
  caused due to an error when processing certain BIND requests. This can
  be exploited to cause a crash by sending specially crafted BIND
  requests to an OpenLDAP server.

  The Common Vulnerabilities and Exposures project has assigned the
  name CVE-2006-5779 to this issue.

* Fri Oct 06 2006 Nived Gopalan <nived at trustix dot org> 2.1.30-6tr
- SECURITY Fix: Howard Chu has reported a security issue in OpenLDAP,
  caused due to an error within the Access Control List processing.
  If a user has "selfwrite" access to an attribute, this can be
  exploited to modify arbitrary values of the attribute.

  The Common Vulnerabilities and Exposures project has assigned the
  name CVE-2006-4600 to this issue.

* Thu Jun 30 2005 Ajith Thampi <ajith at comodo dot com> 2.1.30-5tr
- Fix, openldap when connecting to a slave using TLS, does not use TLS for
  the subsequent connection if the client is referred to a master, which
  causes a password to be sent in cleartext and allows remote attackers to
  sniff the password. (CAN-2005-2069)
		
* Sat May 21 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.1.30-4tr
- Rebuilt with --enable-crypt. Fix Bug #718.

* Tue Apr 19 2005 Syed Shabir Zakiullah <syedshabir at comodo dot com> 2.1.30-3tr
- Changed init priority to 74 26

* Tue Nov  9 2004 Oystein Viggen <oysteivi at trustix dot com> 2.1.30-2tr
- Rebuild with shared openssl

* Mon Sep 27 2004 Erlend Midttun <erlendbm at trustix dot org> 2.1.30-1tr
- New upstream.

* Fri Feb  6 2004 Omar Kilani <ok at trustix dot org> 2.1.25-1ok
- New upstream, 2.1.25 is latest stable release.
- Rebuild against db4-4.2.52.

* Wed Nov 26 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.23-1tr
- New upstream.

* Mon Jun 30 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.22-1tr
- New upstream.

* Fri Jun 27 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.21-5tr
- Removed Kerberos(!).

* Wed Jun 18 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.21-4tr
- Big rebuild

* Tue Jun 17 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.21-3em
- Now with %defattr.

* Mon Jun 16 2003 Gerald Dachs <gda at trustix dot org> 2.1.21-2gd
- fixed permission on /usr/share/openldap

* Fri Jun 13 2003 Erlend Midttun <erlendbm at trustix dot com> 2.1.21-1em
- run as user.
- add migration tools.
- new upstream.
- Added patches from Red Hat

* Fri May 23 2003 Tor Hveem <torh at trustix dot org> 2.1.17-1th
- 2.1.17
- Removed Patch0 and instead have a static slapd.conf, because the
  patch will probably be rejected each time a new upstream arrives.
- Use more macros


* Wed Apr 30 2003 Frode Ramsvik <froder@trustix.com> 2.1.16-5fr
- Fixed initscript (it now actually works) + simple support for 
  TLS startup.
- Database is now saved in /var/lib/openldap.
- slapd configuration file now has examples for TLS support and lists
  the included schemas. (Patch0)
- ldap.conf has examples for TLS client support. (Patch1)
- Build requires tcp_wrappers and cyrus-sasl-devel

* Mon Mar 24 2003 Erlend Midttun <erlendbm@trustix.com> 2.1.16-4em
- Rebuilt against glibc 2.3.2.

* Sun Mar 23 2003 Gerald Dachs <gda@trustix.org> openldap-2.1.16-3gd
- rebuilt Goetz rpm against db-4.0

* Thu Mar 20 2003 Goetz Bock <bock@trustix.org> openldap-2.1.16-2bg
- gda made a 2.1.16-1gd, I merged my changes with his
- new stable version: 2.1.16

* Mon Mar 11 2003 Goetz Bock <bock@trustix.org> openldap-2.1.13-0bg
- new upstream: 2.1.13
- removed ud
- cleaned up spec file
- added some requirements

* Fri Jan 17 2003 Gerald Dachs <gda@trustix.org> 2.1.3-4gd
- recompiled against openssl 0.9.7-1gd 

* Thu Jan  9 2003 Erlend Midttun <erlendbm@trustix.com> 2.1.3-3em
- Use initdir macro.
- Use /mnt/lockdev for lockfiles.
- Remove config(noreplace) for initscript.

* Thu Nov 21 2002 Christian H. Toldnes <christht@trustix.com> 2.1.3-2ct
- ldap initscript now uses $INITLOCK, and correct functions placement.

* Tue Aug 20 2002 Christian H. Toldnes <christht@trustix.com> 2.1.3-1ct
- New upstream version
- Big cleanup
- Package rename to openldap
- Enhanced package split.

* Tue Jun 12 2001 Erlend Midttun <erlendbm@trustix.com>
- changed name to openldap1.
- New upstream version.

* Mon Mar 26 2001 Alexander Reelsen <ar@trustix.com>
- Fixed minor installation problem

* Mon Jan 29 2001 Oystein Viggen <oysteivi@trustix.com>
- chkconfig --add made the service start by default.  Fix the init-script.

* Fri Jan 19 2001 Erlend Midttun <erlendbm@trustix.com>
- Fixed permission on /usr/bin/ud.  No longer group root writeable.
- Force permission 600 on slapd.conf.
- Added chkconfig --add to make it show in list.

* Mon Jan  8 2001 Oystein Viggen <oysteivi@trustix.com>
- Made it not store the database in /var/run

* Thu Sep 14 2000 Per Ivar Paulsen <perp@trustix.com>
- update to 1.2.11

* Mon Feb 10 2000 Per Ivar Paulsen <perp@trustix.com>
- update to 1.2.10

* Mon Feb 10 2000 Per Ivar Paulsen <perp@trustix.com>
- Initial release for the Trustix Secure Linux distribution.
- Added noreplace.
- Moved man and info pages to /usr/share adhering to FHS
- TODO: add better default configuration

* Sun Jan 23 2000 Arne Coucheron <arneco@online.no>
  [1.2.9-1]

* Fri Dec 17 1999 Arne Coucheron <arneco@online.no>
  [1.2.8-1]

* Sat Sep 18 1999 Arne Coucheron <arneco@online.no>
  [1.2.7-1]

* Tue Aug 24 1999 Arne Coucheron <arneco@online.no>
  [1.2.6-1]

* Mon Jun 07 1999 Arne Coucheron <arneco@online.no>
  [1.2.3-1]
- enabled as much options as possible to the compile
- built on RH 6.0

* Thu Apr 22 1999 Arne Coucheron <arneco@online.no>
  [1.2.1-1]
- using %%{name} and %%{version} macros
- added -q parameter to %setup
- added URL tag
- using chkconfig to activate init script and added Prereq: for it
- devel package requires openldap
- fixed the path names in the man pages
- using %defattr in %files section
- simplified the use %files
- some changes in the init script (check that networking is up etc)
